@@ -163,7 +163,7 @@ public class XapianJNI {
 
     public static native void database_finalize(long dbid);
 
-    // writeable-database functions
+    // writable-database functions
     public static native long writabledatabase_new() throws XapianError;
 
     public static native long writabledatabase_new(String path, int mode) throws XapianError;
@@ -351,7 +351,8 @@ public class XapianJNI {
 
     public static native void enquire_set_query(long eid, long queryid, int qlen) throws XapianError;
 
-    public static native long enquire_get_query(long eid) throws XapianError;
+// We implement get_query in Java and don't use JNI or C++ at all for it.
+//    public static native long enquire_get_query(long eid) throws XapianError;
 //    public static native void enquire_set_weighting_scheme(long eid, long weightid) throws XapianError;
     public static native void enquire_set_collapse_key(long eid, long collapse_key) throws XapianError;
 
@@ -360,7 +361,7 @@ public class XapianJNI {
     public static native void enquire_set_cutoff(long eid, int percent_cutoff, double weight_cutoff) throws XapianError;
 
     public static native void enquire_set_sorting(long eid, long sort_key, int sort_bands) throws XapianError;
-//    public static native void enquire_set_bias(long eid, double bias_weight, time_t bias_halflife) throws XapianError;
+
     public static native long enquire_get_mset(long eid, long first, long maxitems, long rsetid, MatchDecider md) throws XapianError;
 
     public static native long enquire_get_eset(long eid, long maxitems, long rsetid, int flags, double k, ExpandDecider ed) throws XapianError;
